<?php
if ( ! class_exists( 'ReduxFrameworkInstances' ) ) {
    return;
}

/*
 * Convert HEX to GRBA
 */
if(!function_exists('gymnaz_rgba')){
    function gymnaz_rgba($hex,$opacity = 1) {
        $hex = str_replace("#",null, $hex);
        $color = array();
        if(strlen($hex) == 3) {
            $color['r'] = hexdec(substr($hex,0,1).substr($hex,0,1));
            $color['g'] = hexdec(substr($hex,1,1).substr($hex,1,1));
            $color['b'] = hexdec(substr($hex,2,1).substr($hex,2,1));
            $color['a'] = $opacity;
        }
        else if(strlen($hex) == 6) {
            $color['r'] = hexdec(substr($hex, 0, 2));
            $color['g'] = hexdec(substr($hex, 2, 2));
            $color['b'] = hexdec(substr($hex, 4, 2));
            $color['a'] = $opacity;
        }
        $color = "rgba(".implode(', ', $color).")";
        return $color;
    }
}

/*
 * Convert HEX to Dark & Lighten
 */
function gymnaz_lighten( $hex, $percent ) {
    
    // validate hex string
    
    $hex = preg_replace( '/[^0-9a-f]/i', '', $hex );
    $new_hex = '#';
    
    if ( strlen( $hex ) < 6 ) {
        $hex = $hex[0] + $hex[0] + $hex[1] + $hex[1] + $hex[2] + $hex[2];
    }
    
    // convert to decimal and change luminosity
    for ($i = 0; $i < 3; $i++) {
        $dec = hexdec( substr( $hex, $i*2, 2 ) );
        $dec = min( max( 0, $dec + $dec * $percent ), 255 ); 
        $new_hex .= str_pad( dechex( $dec ) , 2, 0, STR_PAD_LEFT );
    }       
    
    return $new_hex;
}

class CSS_Generator {
    /**
     * scssc class instance
     *
     * @access protected
     * @var scssc
     */
    protected $scssc = null;

    /**
     * ReduxFramework class instance
     *
     * @access protected
     * @var ReduxFramework
     */
    protected $redux = null;

    /**
     * Debug mode is turn on or not
     *
     * @access protected
     * @var boolean
     */
    protected $dev_mode = true;

    /**
     * opt_name of ReduxFramework
     *
     * @access protected
     * @var string
     */
    protected $opt_name = '';


    /**
     * Constructor
     */
    function __construct() {
        $this->opt_name = gymnaz_get_opt_name();

        if ( empty( $this->opt_name ) ) {
            return;
        }
        $this->dev_mode = gymnaz_get_opt( 'dev_mode', '0' ) === '1' ? true : false;
        add_action( 'wp_enqueue_scripts', array( $this, 'enqueue' ), 10 );        
    }

    /**
     * Hooked wp_enqueue_scripts - 20
     * Make sure that the handle is enqueued from earlier wp_enqueue_scripts hook.
     */
    function enqueue() {
        
        $css = $this->inline_css();
        // wp_add_inline_style( 'gymnaz-theme-abc', $css  );
        

        if ( !empty($css) ) {
            wp_add_inline_style( 'gymnaz-style', $this->dev_mode ? $css : gymnaz_css_minifier( $css ) );
        }
    }

    /**
     * Generate inline css based on theme options
     */
    protected function inline_css() {
        ob_start();
        /* BG Body */
        $body_background = gymnaz_get_opt( 'body_background' );
        $layout_boxed = gymnaz_get_opt( 'layout_boxed', false );
        $layout_boxed_page = gymnaz_get_page_opt( 'layout_boxed', false );
        if($layout_boxed_page) {
            $layout_boxed = $layout_boxed_page;
        }
        if($layout_boxed && isset($body_background)) {
            echo '
            body {
                background-color: '.esc_attr( $body_background['background-color'] ).';
                background-size: '.esc_attr( $body_background['background-size'] ).';
                background-attachment: '.esc_attr( $body_background['background-attachment'] ).';
                background-repeat: '.esc_attr( $body_background['background-repeat'] ).';
                background-position: '.esc_attr( $body_background['background-position'] ).';
                background-image: url('.esc_attr( $body_background['background-image'] ).');
            }';
        }
        

        /* Header */
        $h_bg_color = gymnaz_get_opt( 'h_bg_color' );
        $h_bg_top_color = gymnaz_get_opt( 'h_bg_top_color' );
        $h_text_top_color = gymnaz_get_opt( 'h_text_top_color' );
        $h_link_top_color = gymnaz_get_opt( 'h_link_top_color' );
        $sticky_on = gymnaz_get_opt( 'sticky_on' );
        if(!empty($h_bg_top_color)) {
            echo '#header-wrap #header-topbar {
                background-color: '.esc_attr( $h_bg_top_color ).' !important;
            }';
        }
        if(!empty($h_text_top_color)) {
            echo '#header-wrap #header-topbar, #header-wrap #header-topbar .header-contact i, #header-wrap #header-topbar .header-contact label {
                color: '.esc_attr( $h_text_top_color ).' !important;
            }';
        }
        if(!empty($h_link_top_color)) {
            echo '#header-wrap #header-topbar a {
                color: '.esc_attr( $h_link_top_color ).' !important;
            }';
        }
        if(!empty($h_bg_color)) {
            echo 'header,
            header.sticky {
                background-color: '.esc_attr( $h_bg_color ).';
            }';
        }
        if(!empty($sticky_on)) {
            echo '.affix.sticky-menu {
                position: fixed !important;
            }';
        }

        /* Logo */
        $logo_maxh = gymnaz_get_opt( 'logo_maxh' );

        if (!empty($logo_maxh['height']) && $logo_maxh['height'] != 'px')
        {
            printf( 'header .logo a img { max-height: %s; }', esc_attr($logo_maxh['height']) );
        }

        /* Menu */
        $menu_text_transform = gymnaz_get_opt( 'menu_text_transform' );
        if ( !empty( $menu_text_transform ) ) {
            printf( 'header .menu ul li a { text-transform: %s !important; }', esc_attr($menu_text_transform) );
        }
        $menu_font_size = gymnaz_get_opt( 'menu_font_size' );
        if ( !empty( $menu_font_size ) ) {
            printf( 'header .menu ul li a { font-size: %s'.'px !important; }', esc_attr($menu_font_size) );
        }
        
        $main_menu_color = gymnaz_get_opt( 'main_menu_color' );
        if ( !empty( $main_menu_color['regular'] ) ) {
            printf( 'header .menu ul li a { color: %s !important; }', esc_attr($main_menu_color['regular']) );
        }
        if ( !empty( $main_menu_color['hover'] ) ) {
            printf( 'header .menu ul li a:hover { color: %s !important; }', esc_attr($main_menu_color['hover']) );
        }
        if ( !empty( $main_menu_color['active'] ) ) {
            printf( 'header .menu ul li a.current, .primary-menu > li.current_page_item > a, .primary-menu > li.current-menu-item > a, .primary-menu > li.current_page_ancestor > a, .primary-menu > li.current-menu-ancestor > a { color: %s !important; }', esc_attr($main_menu_color['active']) );
        }

        /* Footer */
        $footer_bg = gymnaz_get_opt( 'footer_bg' );
        $footer_bg_color_top = gymnaz_get_opt( 'footer_bg_color_top' );
        $footer_top_heading_color = gymnaz_get_opt( 'footer_top_heading_color' );
        $footer_top_heading_fs = gymnaz_get_opt( 'footer_top_heading_fs' );
        $footer_top_paddings = gymnaz_get_opt( 'footer_top_paddings' );
        if(!empty($footer_bg['background-color'])) {
            echo '.site-layout-default .site-footer {
                margin-top: 0px;
            }';
            echo '.site-layout-default .site-footer:before {
                display: none;
            }';
        }
        if(!empty($footer_bg_color_top)) {
            echo '.site-footer:before {
                background-color: '.esc_attr( $footer_bg_color_top['rgba'] ).' !important;
            }';
        }
        if(!empty($footer_top_heading_color)) {
            echo '.top-footer .footer-widget-title {
                color: '.esc_attr( $footer_top_heading_color ).' !important;
            }';
        }
        if(!empty($footer_top_heading_fs)) {
            echo '.top-footer .footer-widget-title {
                font-size: '.esc_attr( $footer_top_heading_fs ).'px !important;
            }';
        }
        if ( isset($footer_top_paddings) && !empty($footer_top_paddings) ) {
            if(!empty($footer_top_paddings['padding-top'])) {
                echo ".site-footer {
                    padding-top:" .esc_attr($footer_top_paddings['padding-top']). " !important;
                }";
            }
            if(!empty($footer_top_paddings['padding-bottom'])) {
                echo ".site-footer .top-footer {
                    padding-bottom:" .esc_attr($footer_top_paddings['padding-bottom']). " !important;
                }";
            }
        }

        $color = gymnaz_get_opt( 'primary_color' ,'');
        $custom_header = gymnaz_get_page_opt( 'custom_header', '0');
        if ( is_page() && $custom_header == '1' ) {
            $page_color = gymnaz_get_page_opt('page_color');
            $color = $page_color;
            
            if($color == '0') {
                return;
            }
        }
        if(!empty($color)){
            echo "
                ::-webkit-scrollbar-thumb,
                ::-webkit-scrollbar-thumb:hover {
                    background: " . $color . ";
                }
                .form-control:focus,
                .form-control:hover {
                    border-color: " . $color . " !important;
                }
                .bg-theme{
                    background-color: " . $color . ";
                }
                h5 a:hover, h6 a:hover {
                    color: " . $color . ";
                }
                .c-theme {
                    color:" . $color . ";
                }
                .all-title .title-sep {
                    fill: " . $color . ";
                }
                /*  btn-one */
                .btn-one{
                    background-color: " . $color . ";
                }
                .btn-one:hover,.caption-1 span{
                    color:" . $color . ";
                }


                /*  btn-two */

                .btn-two,.widget_recent_entries li a:hover,.widget_recent_comments li a:hover,.widget_meta li a:hover{
                    color: " . $color . ";
                }

                .btn-two:before, 
                .btn-two:after {
                    border-top-color:" . $color . ";
                    border-bottom-color: " . $color . ";
                }
                #c-scroll:after{
                    border-bottom-color: " . $color . ";
                }
                #c-scroll {
                    background-color: " . $color . ";
                }
                .navbar-nav .nav-item:hover .nav-link,.btn-search {
                    color: " . $color . ";
                }
                .navbar-toggler-icon{
                    background-color: " . $color . ";
                }
                .dropdown-item > a::before {
                    background-color: " . $color . ";
                }
                .navbar-nav .dropdown-menu .dropdown-item:hover>a {
                    color: " . $color . ";
                }

                .service-box2::after{
                    background-color: " . $color . ";
                }

                .title-sep2::after {
                    background-color:" . $color . ";
                }
                .list-2 li:before ,.tagcloud a:hover{
                    background-color:" . $color . "!important;
                }
                .filter-btn.active:before,
                .filter-btn.active:after {
                    background-color: " . $color . ";
                }
                .team-two .t-socials a:hover{
                    color: " . $color . ";
                }
                .team-two:hover,.tagcloud a:hover{
                    border-color:  " . $color . ";
                }
                .team-slider-two.owl-theme .owl-nav [class*=owl-]:hover{
                    color: " . $color . ";  
                 }
                 .service-box3 h5::after {
                    background-color: " . $color . ";
                }
                .service-box:hover .service-content{
                    background-color:" . $color . ";
                    border-color: " . $color . ";
                }
                 .foot-title h4::after {
                    background-color: " . $color . ";
                 }
                 .address i,
                 .news-content p, 
                 .news-content p i,
                 .quick-link li a:hover,
                 .foot-socials a:hover,
                 .foot-bottom a,
                 .quick-link li a:hover::after {
                    color: " . $color . ";
                }
                .navbar-nav .nav-item .mega-heading {
                    color: " . $color . ";
                }
                .cta {
                    background-color: " . $color . ";
                }
                .counter-box:after {
                    background-color: " . $color . ";
                }
                .feature-box:hover h5,
                .banner-link li span {
                    color: " . $color . ";
                }
                .header-three .menu-search a,
                .widget_categories li:hover,
                .widget_archive li:hover{
                    color:" . $color . ";
                }
                .blog-item:hover .date-1,
                .feature-box::after,
                .class-box:hover h5:before, 
                .class-box:hover h5:after{
                    background-color: " . $color . ";
                }
                .price-box .amount::after {
                    background:" . $color . ";
                }
                .price-box .amount::after,
                .amount::before{
                    background-color: " . $color . ";
                }

                .price-box2:hover h5,
                .price-box:hover h5 {
                    color: " . $color . ";
                }
                .price-content h5::after {
                    background-color: " . $color . ";
                }
                .programs-slider-one .swiper-slide-active h5 {
                    color:  " . $color . ";
                }
                .slider-wrap .swiper-button-prev:hover::after, 
                .slider-wrap .swiper-button-next:hover::after {
                    color: " . $color . ";
                }
                .team-one .team-social {
                    background-color:" . $color . ";
                }
                .vid-btn:hover {
                    color: " . $color . ";
                }
                .read-more:hover {
                    color: " . $color . ";
                }

                .post-meta li a:hover {
                    color: " . $color . ";
                }

                .menu-search-form input {
                    border-color: " . $color . ";
                }
                .c-blue,.vid-btn  {
                    color: " . $color . ";
                }
                .bg-blue {
                    background-color:" . $color . ";
                }
                .owl-theme .owl-dots .owl-dot.active span,
                .owl-theme .owl-dots .owl-dot:hover span {
                    background: " . $color . "
                }
                .header-one .menu-search a {
                    background-color: " . $color . ";
                }
                .head-top-one {
                    background-color: " . $color . ";
                }
                .header-one:after {
                    background-color: " . $color . ";
                }
                .head-top-one:after {
                    background-color: " . $color . ";
                }
                .class-3slider.owl-theme .owl-nav [class*=owl-]:hover {
                    color: " . $color . "
                }
                .post-meta li a:hover {
                    color: " . $color . "
                }
                .blog-detail .post-meta li i {
                    color: " . $color . ";
                }
                blockquote {
                    border-left: 5px solid " . $color . ";
                }
                .share .jssocials-share:hover a {
                    color: " . $color . ";
                }
                .post-tags a:hover {
                    color: " . $color . ";
                }
                .aut-img span {
                    border: 2px solid " . $color . ";
                }
                .says {
                    color: " . $color . ";
                }
                .comment-meta a {
                    color: " . $color . ";
                }
                .reply:hover {
                    background-color: " . $color . ";
                }
                .project:hover .proj-content {
                    background-color: " . $color . "
                }
                .search-box .input-group-btn button {
                    background-color: " . $color . ";
                }
                .tagcloud li a:hover {
                    border-color: " . $color . ";
                    background-color: " . $color . ";
                }
                .widget-tabs {
                    border-bottom: 1px solid " . $color . ";
                }
                .widget-tabs a.active {
                    background-color: " . $color . ";
                }
                .page-numbers:hover {
                    background-color: " . $color . ";
                    border-color: " . $color . ";
                }
                .page-numbers.prev:hover,
                .page-numbers.next:hover {
                   color: " . $color . ";
                }
                .pagination-blog a:hover {
                    color: " . $color . ";
                }
            ";
        }

        echo"
            .about-2::after {
                background-image: url(".ASSETS."/img/abt2-bg.jpg);
            }
        ";

        

        /* Custom Css */
        $custom_css = gymnaz_get_opt( 'site_css' );
        if(!empty($custom_css)) { echo esc_attr($custom_css); }

        

        return ob_get_clean();
    }
    protected function print_css( $color ) {

    }
}

new CSS_Generator();