<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  Gymnaz_Post_Metabox $metabox
 */

/**
 * Get list menu.
 * @return array
 */
function gymnaz_get_nav_menu(){

    $menus = array(
        '' => esc_html__('Default', 'gymnaz-pro')
    );

    $obj_menus = wp_get_nav_menus();

    foreach ($obj_menus as $obj_menu){
        $menus[$obj_menu->term_id] = $obj_menu->name;
    }

    return $menus;
}

function gymnaz_page_options_register( $metabox ) {
	if ( ! $metabox->isset_args( 'post' ) ) {
		$metabox->set_args( 'post', array(
			'opt_name'            => 'post_option',
			'display_name'        => esc_html__( 'Post Settings', 'gymnaz-pro' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'page' ) ) {
		$metabox->set_args( 'page', array(
			'opt_name'            => gymnaz_get_page_opt_name(),
			'display_name'        => esc_html__( 'Page Settings', 'gymnaz-pro' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}


	
	

	/**
	 * Config page meta options
	 *
	*/

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Header', 'gymnaz-pro' ),
		'desc'   => esc_html__( 'Header settings for the page.', 'gymnaz-pro' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'      => 'custom_header',
				'type'    => 'switch',
		        'desc'   => esc_html__( 'Header settings for the page.', 'gymnaz-pro' ),
				'title'   => esc_html__( 'Custom Header', 'gymnaz-pro' ),
				'default' => false,
				'indent'  => true
			),

			array(
	            'id'       => 'page_logo',
	            'type'     => 'media',
	            'title'    => esc_html__('Logo', 'gymnaz-pro'),
	            'default' => array(
	                'url'=>get_template_directory_uri().'/assets/img/logo.png'
	            ),
	            'required' => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
	        ),


			array(
	            'id' => 'page-header-preset',
	            'type'     => 'image_select',
	            'title'    => __( 'Select Header Layout','gymnaz-pro' ),
	            'subtitle' => __( 'You can switch your header menu preset/styles from here ', 'gymnaz-pro' ),
	            'desc'     => __( '', 'gymnaz-pro' ),
	            //Must provide key => value pairs for select options
	            'options'  => array(
	                '1' => array('title' => 'Preset 1', 'img' => get_template_directory_uri().'/assets/img/presets/preset-1.png'),
	                '2' => array('title' => 'Preset 2', 'img' => get_template_directory_uri().'/assets/img/presets/preset-2.png'),
	                '3' => array('title' => 'Preset 3', 'img' => get_template_directory_uri().'/assets/img/presets/preset-3.png'),
	            ),
	            'default'  => '1',
	            'required' => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
			),  
			array(
	            'id'          => 'page_color',
	            'type'        => 'color',
	            'title'       => esc_html__('Color', 'gymnaz-pro'),
	            'transparent' => false,
	            'default'     => '#5aaf29',
	            'required' => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
	        ), 

		)
	) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Page Title', 'gymnaz-pro' ),
		'icon'   => 'el-icon-map-marker',
		'fields' => array(
			array(
	            'id'       => 'ptitle_on',
	            'type'     => 'button_set',
	            'title'    => esc_html__('Displayed', 'gymnaz-pro'),
	            'options'  => array(
	                'show'  => esc_html__('Show', 'gymnaz-pro'),
	                'hidden'  => esc_html__('Hidden', 'gymnaz-pro'),
	            ),
	            'default'  => 'hidden'
	        ),
			array(
				'id'       => 'ptitle_background',
				'type'     => 'background',
				'title'    => esc_html__('Background', 'gymnaz-pro'),
				'output'   => array('background'=> '.page-banner'),
				'required' => array( 0 => 'ptitle_on', 1 => 'equals', 2 => 'show' ),
				'force_output' => true,
				'default' => array(
					'background-repeat' => 'no-repeat',
					'background-position' => 'center top',
					'background-attachment' => 'fixed',
					'background-image' => get_template_directory_uri().'/assets/img/blog-banner-bg.jpg',

				),
				'background-color' =>false,
			),
			array(
				'id'           => 'page_overlay',
				'type'         => 'color_rgba',
				'title'        => esc_html__( 'Overley', 'gymnaz-pro' ),
				'output'   => array('background'=> '.page-banner:after'),
	            'default'  		=> '#000',
				'required' 		=> array( 0 => 'ptitle_on', 1 => 'equals', 2 => 'show' ),
				'force_output' 	=> true,
			),
		)
	) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Content', 'gymnaz-pro' ),
		'desc'   => esc_html__( 'Settings for content area.', 'gymnaz-pro' ),
		'icon'   => 'el-icon-pencil',
		'fields' => array(

			array(
				'id'             => 'content_padding',
				'type'           => 'spacing',
				'output'         => array( '#content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'gymnaz-pro' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'gymnaz-pro' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
			array(
				'id'      => 'show_sidebar_page',
				'type'    => 'switch',
				'title'   => esc_html__( 'Show Sidebar', 'gymnaz-pro' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'sidebar_page_pos',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Sidebar Position', 'gymnaz-pro' ),
				'options'      => array(
					'left'  => esc_html__( 'Left', 'gymnaz-pro' ),
					'right' => esc_html__( 'Right', 'gymnaz-pro' ),
				),
				'default'      => 'right',
				'required'     => array( 0 => 'show_sidebar_page', 1 => '=', 2 => '1' ),
				'force_output' => true
			),
			
		)
	) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Footer', 'gymnaz-pro' ),
		'desc'   => esc_html__( 'Footer settings for the page.', 'gymnaz-pro' ),
		'icon'   => 'el-icon-website',
		'fields' => array(

			array(
				'id'      => 'custom_footer',
				'type'    => 'switch',
		        'desc'   => esc_html__( 'Footer settings for the page.', 'gymnaz-pro' ),
				'title'   => esc_html__( 'Custom Footer', 'gymnaz-pro' ),
				'default' => false,
				'indent'  => true
			),
			
			array(
	            'id' => 'page-footer-style',
	            'type'     => 'select',
	            'title'    => __( 'Select Footer Style','gymnaz-pro' ),
	            'subtitle' => __( '', 'gymnaz-pro' ),
	            'desc'     => __( '', 'gymnaz-pro' ),
	            //Must provide key => value pairs for select options
	            'options'  => array(
	                'one' => 'Style 1',
	                'two' => 'Style 2',
	                'three' => 'Style 3',
	            ),
	            'default'  => 'one',
	            'required' => array( 0 => 'custom_footer', 1 => 'equals', 2 => '1' ),
			),

			array(
	            'id'       => 'page-nf-img',
	            'type'     => 'background',
	            'title'    => __( 'Background Image', 'gymnaz-pro' ),
	            'output'   => array('background'=> '.footer-two .foot-top'),
	            'background-color' => false, 
	            'background-position' => false,
	            'background-attachment' => false,
	            'background-repeat' => false,
	            'background-clip' => false,
	            'background-size' => false,
	            'force_output' => true,
	            'default' => array(
	                'background-image' => get_template_directory_uri().'/assets/img/foot-bg.jpg',
	            ),
	            'required' => array( 'page-footer-style', '=', 'two' ),
	        ),  

		)
	) );
}

add_action( 'cms_post_metabox_register', 'gymnaz_page_options_register' );

function gymnaz_get_option_of_theme_options( $key, $default = '' ) {
	if ( empty( $key ) ) {
		return '';
	}
	$options = get_option( gymnaz_get_opt_name(), array() );
	$value   = isset( $options[ $key ] ) ? $options[ $key ] : $default;
	return $value;
}