<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Gymnaz
 */

#-----------------------------------------------------------------#
# plugin activation 
#-----------------------------------------------------------------#	
require_once THEME_DIR . '/inc/require-plugins.php';	

function theme_vc_elements() {
    if (class_exists('DSShortCode')) {
        cms_require_folder('vc_elements', THEME_DIR );
    }
}
add_action('vc_before_init', 'theme_vc_elements');


#-----------------------------------------------------------------#
# Change The Default WordPress Excerpt Length
#-----------------------------------------------------------------#
if ( ! function_exists( 'theme_custom_excerpt' ) ) {
	function theme_custom_excerpt($limit) {

		$excerpt = explode(' ', get_the_excerpt(), $limit);
	
		if ( count($excerpt) >= $limit ) {
			array_pop($excerpt);
			$excerpt = implode(" ", $excerpt) . '...';
		} else {
			$excerpt = implode(" ", $excerpt);
		}
		$excerpt = preg_replace('`\[[^\]]*\]`', '', $excerpt);
	
		return $excerpt;
	}
	
}

/**
 * Commnet Form
 */
function gymnaz_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'gymnaz_comment_field_to_bottom' );

function theme_excerpt_global_length( $length ) {
  return 20;
}

// Theme Except Functions 
function theme_excerpt(){
  add_filter( 'excerpt_length', 'theme_excerpt_global_length', 999 );
  echo get_the_excerpt();
}

function gymnaz_author_social_icons( $contactmethods ) {
	
	$contactmethods['facebook'] = 'Facebook Link';
	$contactmethods['twitter'] = 'Twitter Link';
	$contactmethods['google_plus'] = 'Google Plus Link';
	$contactmethods['linkedin'] = 'Linkedin Link';
	$contactmethods['instagram'] = 'Instagram Link';
	
	return $contactmethods;
}
add_filter('user_contactmethods','gymnaz_author_social_icons', 10, 1);


/**
 * Prints posts pagination based on query
 *
 * @param  WP_Query $query     Custom query, if left blank, this will use global query ( current query )
 * @return void
 */
function theme_pagination( $query = null ) {
    $classes = array();

    if ( empty( $query ) )
    {
        $query = $GLOBALS['wp_query'];
    }

    if ( empty( $query->max_num_pages ) || ! is_numeric( $query->max_num_pages ) || $query->max_num_pages < 2 )
    {
        return;
    }

    $paged = get_query_var( 'paged' );

    if ( ! $paged && is_front_page() && ! is_home() )
    {
        $paged = get_query_var( 'page' );
    }

    $paged = $paged ? intval( $paged ) : 1;

    $pagenum_link = html_entity_decode( get_pagenum_link() );
    $query_args   = array();
    $url_parts    = explode( '?', $pagenum_link );

    if ( isset( $url_parts[1] ) )
    {
        wp_parse_str( $url_parts[1], $query_args );
    }

    $pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

    $html_prev = '<i class="fa fa-angle-left"></i> Prev';
    $html_next = 'Next <i class="fa fa-angle-right"></i>';
    $links = paginate_links( array(
        'base'     => $pagenum_link,
        'total'    => $query->max_num_pages,
        'current'  => $paged,
        'type'  => 'plain',
        'mid_size' => 1,
        'add_args' => array_map( 'urlencode', $query_args ),
        'prev_text' => $html_prev,
        'next_text' => $html_next,
	) );

    $template = '<div class="pagination mt-30">%2$s</div></nav>';

    if ( $links )
    {
        printf(
            wp_kses_post($template),
            esc_html__( 'Navigation', 'gymnaz-pro' ),
            wp_kses_post($links)
        );
    }
}


/**
 * Custom Comment List
*/
function gymnaz_comment_list( $comment, $args, $depth ) {
	if ( 'div' === $args['style'] ) {
        $tag       = 'div';
        $add_below = 'comment';
    } else {
        $tag       = 'li';
        $add_below = 'div-comment';
    }
    ?>
    <<?php echo ''.$tag ?> <?php comment_class( empty( $args['has_children'] ) ? 'comment-item ' : 'comment-item parent' ) ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
        <div id="div-comment-<?php comment_ID() ?>" class="comment-body">
            <?php endif; ?>
				<div class="comment-author"> 
					<?php if ($args['avatar_size'] != 0) echo get_avatar($comment, $args['avatar_size']); ?>
					<b class="fn">
                        <a href="#"><?php printf('%s', get_comment_author_link()); ?></a>
                    </b>
                    <span class="says"> says:</span> 
				</div>
				<div class="comment-meta">
                    <a href="#"><?php echo get_comment_date() . ' at ' . get_comment_time(); ?></a>
                </div>
                <?php comment_text(); ?>
				<div class="reply">
					<?php comment_reply_link(array_merge($args, array('add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
				</div>
            <?php if ( 'div' != $args['style'] ) : ?>
        </div>
    <?php endif;
}

/* Favicon */
function gymnaz_site_favicon(){
    
    $favicon = gymnaz_get_opt( 'favicon' );
    
    if(!empty($favicon['url']))
        echo '<link rel="icon" type="image/png" href="'.esc_url($favicon['url']).'"/>';
}
add_action('wp_head', 'gymnaz_site_favicon',1);

/**
 * Page title layout
 **/
function gymnaz_page_title_layout() {
    get_template_part( 'template-parts/page-header', '' );
}

/**
 * Get page title and description.
 *
 * @return array Contains 'title'
 */
function gymnaz_get_page_titles() {
	$title = '';

	// Default titles
	if ( ! is_archive() ) {
		// Posts page view
		if ( is_home() ) {
			// Only available if posts page is set.
			if ( ! is_front_page() && $page_for_posts = get_option( 'page_for_posts' ) ) {
				$title = get_post_meta( $page_for_posts, 'custom_title', true );
				if ( empty( $title ) ) {
					$title = get_the_title( $page_for_posts );
				}
			}
			if ( is_front_page() ) {
				$title = esc_html__( 'Blog', 'gymnaz-pro' );
			}
		} // Single page view
        elseif ( is_page() ) {
			$title = get_post_meta( get_the_ID(), 'custom_title', true );
			if ( ! $title ) {
				$title = get_the_title();
			}
		} elseif ( is_404() ) {
			$title = esc_html__( '404', 'gymnaz-pro' );
		} elseif ( is_search() ) {
			$title = esc_html__( 'Search results', 'gymnaz-pro' );
		} else {
			$title = get_post_meta( get_the_ID(), 'custom_title', true );
			if ( ! $title ) {
				$title = get_the_title();
			}
		}
	} elseif ( is_author() ) {
		$title = esc_html__( 'Author:', 'gymnaz-pro' ) . ' ' . get_the_author();
	} // Author
	else {
		$title = get_the_archive_title();
	}

	return array(
		'title' => $title,
	);
}

/***************** Create the breadcrumbs ******************/

if (!function_exists('gymnaz_breadcrumbs')) {
    
    function gymnaz_breadcrumbs() {

        $showOnHome = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show

        $home = __('Home', 'gymnaz-pro'); // text for the 'Home' link

        $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show

        global $post;

        $homeLink = home_url();

        if (is_home() || is_front_page()) {
            if ($showOnHome == 1) echo '<li><a href="'.$homeLink.'">'.$home.'</a></li>';
        }
        else {
            echo '<li><a href="'.$homeLink.'">'.$home.'</a></li>';
            echo '<li>';

            if ( is_category() ) {
              
                global $wp_query;

                $cat_obj = $wp_query->get_queried_object();

                $thisCat = $cat_obj->term_id;

                $thisCat = get_category($thisCat);

                $parentCat = get_category($thisCat->parent);

                if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' '));

                echo '<span class="active">'. __('Archive by category', 'gymnaz-pro').' "' . single_cat_title('', false) . '"'."</span>";

            }
            elseif ( is_search() ) {
         
                echo '<span class="active">'.__('Search results for', 'gymnaz-pro').' "' . get_search_query() . '"'."</span>";
            }
            elseif ( is_day() ) {
              
                echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ';

                echo '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ';

                echo '<span class="active">'.get_the_time('d')."</span>";
            }
            elseif ( is_month() ) {
             
                echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ';

                echo '<span class="active">'.get_the_time('F')."</span>";

            }
            elseif ( is_year() ) {
            
                echo '<span class="active">'.get_the_time('Y')."</span>";

            }
            elseif ( is_single() && !is_attachment() ) {
            
                if ( get_post_type() != 'post' ) {

                    $post_type = get_post_type_object(get_post_type());

                    $slug = $post_type->rewrite;

                    echo '<a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $slug['slug'] . '</a>';

                    if ($showCurrent == 1) echo '<span class="active">'.get_the_title().'</span>';
                }
                else {
             
                    $cat = get_the_category(); $cat = $cat[0];

                    is_wp_error( $cats = get_category_parents($cat, TRUE, ' ') ) ? '' : $cats; 

                    if ($showCurrent == 0) $cats = preg_replace("/^(.+)\s \s$/", "$1", $cats);

                    if ($showCurrent == 1) echo '<span class="active">'.get_the_title().'</span>';
                }
            }
            elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {

                $post_type = get_post_type_object(get_post_type());

                echo _($post_type->labels->singular_name);
            }
            elseif ( is_attachment() ) {
                    
                $parent = get_post($post->post_parent);

                $cat = get_the_category($parent->ID); $cat = $cat[0];

                if ($cat || !is_wp_error($cat) ){
                    echo get_category_parents($cat, TRUE, ' ');
                }

                echo get_category_parents($cat, TRUE, ' ');

                echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a>';

                if ($showCurrent == 1) echo '<span class="active">'.get_the_title().'</span>';
            }
            elseif ( is_page() && !$post->post_parent ) {

                if ($showCurrent == 1) echo '<span class="active">'.get_the_title().'</span>';
            }
            elseif ( is_page() && $post->post_parent ) {

                $parent_id  = $post->post_parent;

                $breadcrumbs = array();

                while ($parent_id) {

                    $page = get_page($parent_id);

                    $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a> ';

                    $parent_id  = $page->post_parent;
                }

                $breadcrumbs = array_reverse($breadcrumbs);

                foreach ($breadcrumbs as $crumb) echo !empty( $crumb ) ? $crumb : '';

                if ($showCurrent == 1) echo '<span class="active">'.get_the_title().'</span>';

            }
            elseif ( is_tag() ) {

                echo '<span class="active">'.__('Posts tagged for ', 'gymnaz-pro').' "' . single_tag_title('', false) . '"'.'</span>';

            }
            elseif ( is_author() ) {

                global $author;

                $userdata = get_userdata($author);

                echo '<span class="active">'.__('Articles posted by', 'gymnaz-pro').' ' . $userdata->display_name.'</span>';

            }
            elseif ( is_404() ) {

                echo '<span class="active">'.__('Error 404', 'gymnaz-pro').'</span>';

            }

            if ( get_query_var('paged') ) {

                if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';

                echo __('Page', 'gymnaz-pro') . ' ' . get_query_var('paged');

                if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
            }

            echo '</li>';
        }
    }
}


//  Function From Ref Theme

/**
 * Get opt_name for Redux Framework options instance args and for
 * getting option value.
 *
 * @return string
 */
function gymnaz_get_opt_name() {
	return apply_filters( 'gymnaz_opt_name', 'cms_theme_options' );
}

/**
 * Get theme option based on its id.
 *
 * @param  string $opt_id Required. the option id.
 * @param  mixed $default Optional. Default if the option is not found or not yet saved.
 *                         If not set, false will be used
 *
 * @return mixed
 */
function gymnaz_get_opt( $opt_id, $default = false ) {
	$opt_name = gymnaz_get_opt_name();
	if ( empty( $opt_name ) ) {
		return $default;
	}

	global ${$opt_name};
	if ( ! isset( ${$opt_name} ) || ! isset( ${$opt_name}[ $opt_id ] ) ) {
		$options = get_option( $opt_name );
	} else {
		$options = ${$opt_name};
	}
	if ( ! isset( $options ) || ! isset( $options[ $opt_id ] ) || $options[ $opt_id ] === '' ) {
		return $default;
	}
	if ( is_array( $options[ $opt_id ] ) && is_array( $default ) ) {
		foreach ( $options[ $opt_id ] as $key => $value ) {
			if ( isset( $default[ $key ] ) && $value === '' ) {
				$options[ $opt_id ][ $key ] = $default[ $key ];
			}
		}
	}

	return $options[ $opt_id ];
}

/**
 * Get opt_name for Redux Framework options instance args and for
 * getting option value.
 *
 * @return string
 */
function gymnaz_get_page_opt_name() {
	return apply_filters( 'gymnaz_page_opt_name', 'cms_page_options' );
}

/**
 * Get Post List 
*/
if(!function_exists('gymnaz_list_post')){
    function gymnaz_list_post($post_type = 'post', $default = false){
        $post_list = array();
        $posts = get_posts(array('post_type' => $post_type,'posts_per_page' => '-1'));
        foreach($posts as $post){
            $post_list[$post->post_name] = $post->post_title;
        }
        return $post_list;
    }
}


/**
 * Check if provided color string is valid color.
 * Only supports 'transparent', HEX, RGB, RGBA.
 *
 * @param  string $color
 *
 * @return boolean
 */
function gymnaz_is_valid_color( $color ) {
	$color = preg_replace( "/\s+/m", '', $color );

	if ( $color === 'transparent' ) {
		return true;
	}

	if ( '' == $color ) {
		return false;
	}

	// Hex format
	if ( preg_match( "/(?:^#[a-fA-F0-9]{6}$)|(?:^#[a-fA-F0-9]{3}$)/", $color ) ) {
		return true;
	}

	// rgb or rgba format
	if ( preg_match( "/(?:^rgba\(\d+\,\d+\,\d+\,(?:\d*(?:\.\d+)?)\)$)|(?:^rgb\(\d+\,\d+\,\d+\)$)/", $color ) ) {
		preg_match_all( "/\d+\.*\d*/", $color, $matches );
		if ( empty( $matches ) || empty( $matches[0] ) ) {
			return false;
		}

		$red   = empty( $matches[0][0] ) ? $matches[0][0] : 0;
		$green = empty( $matches[0][1] ) ? $matches[0][1] : 0;
		$blue  = empty( $matches[0][2] ) ? $matches[0][2] : 0;
		$alpha = empty( $matches[0][3] ) ? $matches[0][3] : 1;

		if ( $red < 0 || $red > 255 || $green < 0 || $green > 255 || $blue < 0 || $blue > 255 || $alpha < 0 || $alpha > 1.0 ) {
			return false;
		}
	} else {
		return false;
	}

	return true;
}

/**
 * Get theme option based on its id.
 *
 * @param  string $opt_id Required. the option id.
 * @param  mixed $default Optional. Default if the option is not found or not yet saved.
 *                         If not set, false will be used
 *
 * @return mixed
 */
function gymnaz_get_page_opt( $opt_id, $default = false ) {
	$page_opt_name = gymnaz_get_page_opt_name();
	if ( empty( $page_opt_name ) ) {
		return $default;
	}
	$id = get_the_ID();
	if ( ! is_archive() && is_home() ) {
		if ( ! is_front_page() ) {
			$page_for_posts = get_option( 'page_for_posts' );
			$id             = $page_for_posts;
		}
	}

	return $options = ! empty($id) ? get_post_meta( intval( $id ), $opt_id, true ) : $default;
}

function gymnaz_vc_shortcode_css_class( $classes, $settings_base, $atts ) {
    $classes_arr = explode( ' ', $classes );

    if ( 'vc_row' == $settings_base ) {
        if ( $atts['gymnaz_row_class'] ) {
            $classes_arr[] = $atts['gymnaz_row_class'];
        }
        if ( $atts['bg_image_position'] ) {
            $classes_arr[] = $atts['bg_image_position'];
        }
	}

    
    if ( 'vc_row_inner' == $settings_base ) {
        if ( $atts['row_border_box'] ) {
            $classes_arr[] = $atts['row_border_box'];
        }
    }

    if ( isset($atts['animation_column']) && $atts['animation_column'] ) {
        wp_enqueue_style( 'animate-css' );
        $classes_arr[] = 'wpb_animate_when_almost_visible '.' wpb_'.$atts['animation_column'].' '.$atts['animation_column'];
    }

    if ( 'vc_column_inner' == $settings_base ) {
		if ( $atts['ct_column_inner_class'] ) {
			$classes_arr[] = $atts['ct_column_inner_class'];
        }
    }
    if ( 'vc_column' == $settings_base ) {
		if ( $atts['ct_column_class'] ) {
			$classes_arr[] = $atts['ct_column_class'];
        }
    }

    if ( 'vc_single_image' == $settings_base ) {
        if ( $atts['ct_image_align'] ) {
            $classes_arr[] = $atts['ct_image_align'];
        }
        if ( $atts['ct_image_align_md'] ) {
            $classes_arr[] = $atts['ct_image_align_md'];
		}
    }

    if ( 'vc_column_text' == $settings_base ) {
        if ( $atts['text_align'] ) {
            $classes_arr[] = $atts['text_align'];
        }
    }

    return implode( ' ', $classes_arr );
}


if ( class_exists( 'WPBakeryShortCode' ) ) {
    add_filter( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, 'gymnaz_vc_shortcode_css_class', 10, 3 );
}

/**
 * Minify css
 *
 * @param  string $css
 *
 * @return string
 */
function gymnaz_css_minifier( $css ) {
	// Normalize whitespace
	$css = preg_replace( '/\s+/', ' ', $css );
	// Remove spaces before and after comment
	$css = preg_replace( '/(\s+)(\/\*(.*?)\*\/)(\s+)/', '$2', $css );
	// Remove comment blocks, everything between /* and */, unless
	// preserved with /*! ... */ or /** ... */
	$css = preg_replace( '~/\*(?![\!|\*])(.*?)\*/~', '', $css );
	// Remove ; before }
	$css = preg_replace( '/;(?=\s*})/', '', $css );
	// Remove space after , : ; { } */ >
	$css = preg_replace( '/(,|:|;|\{|}|\*\/|>) /', '$1', $css );
	// Remove space before , ; { } ( ) >
	$css = preg_replace( '/ (,|;|\{|}|\(|\)|>)/', '$1', $css );
	// Strips leading 0 on decimal values (converts 0.5px into .5px)
	$css = preg_replace( '/(:| )0\.([0-9]+)(%|em|ex|px|in|cm|mm|pt|pc)/i', '${1}.${2}${3}', $css );
	// Strips units if value is 0 (converts 0px to 0)
	$css = preg_replace( '/(:| )(\.?)0(%|em|ex|px|in|cm|mm|pt|pc)/i', '${1}0', $css );
	// Converts all zeros value into short-hand
	$css = preg_replace( '/0 0 0 0/', '0', $css );
	// Shortern 6-character hex color codes to 3-character where possible
	$css = preg_replace( '/#([a-f0-9])\\1([a-f0-9])\\2([a-f0-9])\\3/i', '#\1\2\3', $css );

	return trim( $css );
}

/**
 * Header layout
**/
function gymnaz_header_layout() {
    $header_preset = gymnaz_get_opt( 'header-preset' ,'1');
    $custom_header = gymnaz_get_page_opt( 'custom_header', '0');
    if ( is_page() && $custom_header == '1' ) {
        $page_header_layout = gymnaz_get_page_opt('page-header-preset');
        $header_preset = $page_header_layout;
        
        if($header_preset == '0') {
            return;
        }
    }

	get_template_part( 'template-parts/header/header',$header_preset );
}


/**
 * Header Tracking Code to wp_head hook.
 */
function gymnaz_header_code() {
	$site_header_code = gymnaz_get_opt( 'site_header_code' );
	if ( $site_header_code !== '' ) {
		print wp_kses( $site_header_code, wp_kses_allowed_html() );
	}
}

add_action( 'wp_head', 'gymnaz_header_code' );

/**
 * Footer Tracking Code to wp_footer hook.
 */
function gymnaz_footer_code() {
	$site_footer_code = gymnaz_get_opt( 'site_footer_code' );
	if ( $site_footer_code !== '' ) {
		print wp_kses( $site_footer_code, wp_kses_allowed_html() );
	}
}

add_action( 'wp_footer', 'gymnaz_footer_code' );

if ( ! function_exists( 'gymnaz_customize_search_form' ) ) :

	/** Customize search form.
	 **/
	function gymnaz_customize_search_form() {

		$form = '<div class="search-box"><form method="post" id="searchform" action="' . esc_url( home_url( '/' ) ) . '"><div class="input-group">
		  <input type="text" class="form-control" placeholder="' . esc_attr_x( 'Enter your keywords...', 'placeholder', 'gymnaz-pro' ) . '" value="' . get_search_query() . '" name="s" />
			<span class="input-group-btn">
                <button type="submit" class="fa fa-search"></button>
            </span></div></form></div>';
		return $form;
	}
	
endif;

add_filter( 'get_search_form', 'gymnaz_customize_search_form', 15 );

/*
 * Set post views count using post meta
*/
function setPostViews($postID) {
    $countKey = 'post_views_count';
    $count = get_post_meta($postID, $countKey, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $countKey);
        add_post_meta($postID, $countKey, '0');
    }else{
        $count++;
        update_post_meta($postID, $countKey, $count);
    }
}

// Show views
function getPostViews($postID) {
  $count_key = 'post_views_count';
  $count = get_post_meta($postID, $count_key, true);
  if($count=='') {
    delete_post_meta($postID, $count_key);
    add_post_meta($postID, $count_key, '0');
    return "0";
  }
  return $count;
}

#Get all portfolio category inline

function showPortCategory($port_cats = "")
{
    if (!isset($term_list)) {
        $term_list = '';
    }
   
    $permalink = get_permalink();
    $args = array('taxonomy' => 'catportfolio', 'hide_empty' => true);
    $terms = get_terms('catportfolio', $args);

    $count = count($terms);
    $i = 0;
    $iterm = 1;
    if ($count > 0) {
        if (!isset($_GET['slug'])) $all_current = 'active';
        $cape_list = '';
        $term_list .= '<li class="filter-btn '.$all_current.'" data-filter="*"><span>'. __('All', 'gymnaz-pro') .'</span></li>';
        $termcount = count($terms);
 
        if($port_cats[0] !== 'all' && $port_cats[0] !== '') {
            foreach ( $port_cats as $port_cat ) {
                $term = get_term_by('slug', $port_cat, 'catportfolio' );
                $term_list .= '<li class="filter-btn" data-filter=".'.$term->slug .'"><span>'.$term->name.'</span></li>';
            }
        }
        else {
            if (is_array($terms)) {
                foreach ($terms as $term) {
                    $i++;
                    $permalink = esc_url(add_query_arg("slug", $term->slug, $permalink));
                    $term_list .= '<li class="filter-btn" data-filter=".'.$term->slug.'" ';
                    if (isset($_GET['slug'])) {
                        $getslug = $_GET['slug'];
                    } else {
                        $getslug = '';
                    }
                    if (strnatcasecmp($getslug, $term->name) == 0) $term_list .= 'class="filter-btn active"';
                    $tempname = strtr($term->name, array(
                        ' ' => '-',
                    ));
                    $tempname = strtolower($tempname);
                    $term_list .= '><span>'. $term->name . '</span></li>';
                    if ($count != $i) $term_list .= ' '; else $term_list .= '';
                    if ($iterm<$termcount) {$term_list .= '';}
                    $iterm++;
                }
            }
        }

        echo '<ul class="sorting text-center mb-60">' . $term_list . '</ul>';
    }
}